@@ -26,7 +26,6 @@
 #include <glib/gi18n-lib.h>
 #include <libsyncdaemon/libsyncdaemon.h>
 #include "context-menu.h"
-#include "share-dialog.h"
 
 typedef struct {
 	UbuntuOneNautilus *uon;
@@ -141,55 +140,6 @@ toggle_publicity_cb (NautilusMenuItem * item, gpointer user_data)
 	file_watcher_update_path (data->uon->file_watcher, data->path);
 }
 
-static void
-share_folder_cb (NautilusMenuItem *item, gpointer user_data)
-{
-	MenuCallbackData * data = (MenuCallbackData *) user_data;
-	GtkWidget * dialog;
-
-	dialog = share_dialog_new (data->parent, data->uon, data->path);
-	gtk_widget_show (dialog);
-}
-
-static void
-unshare_folder_cb (NautilusMenuItem *item, gpointer user_data)
-{
-	MenuCallbackData * data = (MenuCallbackData *) user_data;
-	SyncdaemonSharesInterface *interface;
-
-	interface = (SyncdaemonSharesInterface *) syncdaemon_daemon_get_shares_interface (data->uon->syncdaemon);
-	if (interface != NULL)
-		syncdaemon_shares_interface_delete (interface, data->path);
-}
-
-gboolean
-check_share_offer_pending (UbuntuOneNautilus *uon, const gchar *path)
-{
-	GSList *shares, *l;
-	SyncdaemonInterface *interface;
-	gboolean is_share_offer_pending = FALSE;
-	const gchar *node_id;
-
-	interface = syncdaemon_daemon_get_shares_interface (uon->syncdaemon);
-	if (SYNCDAEMON_IS_SHARES_INTERFACE (interface)) {
-		shares = syncdaemon_shares_interface_get_shared (SYNCDAEMON_SHARES_INTERFACE (interface));
-		for (l = shares; l != NULL; l = l->next) {
-			SyncdaemonShareInfo *share_info = SYNCDAEMON_SHARE_INFO (l->data);
-
-			if (g_strcmp0 (syncdaemon_share_info_get_path (share_info), path) == 0) {
-				node_id = syncdaemon_share_info_get_node_id (share_info);
-				if (node_id == NULL)
-					is_share_offer_pending = TRUE;
-				break;
-			}
-		}
-
-		g_slist_free (shares);
-	}
-
-	return is_share_offer_pending;
-}
-
 NautilusMenuItem *
 context_menu_new (UbuntuOneNautilus *uon,
 		  GtkWidget *window,
@@ -201,12 +151,10 @@ context_menu_new (UbuntuOneNautilus *uon,
 	gchar *path, *item, *homedir_path, *path_uri;
 	gboolean is_managed, is_root, is_udf, is_public, is_shared, is_pending;
 	gboolean is_shared_to_me, is_inhome, is_dir, is_regular, is_symlink;
-	gboolean is_share_offer_pending;
 	MenuCallbackData *cb_data;
 
 	is_managed = is_root = is_udf = is_public = is_shared = is_pending = FALSE;
 	is_shared_to_me = is_inhome = is_dir = is_regular = is_symlink = FALSE;
-	is_share_offer_pending = FALSE;
 
 	if (g_list_length (files) != 1)
 		return NULL;
@@ -239,8 +187,6 @@ context_menu_new (UbuntuOneNautilus *uon,
 
 	if (ubuntuone_is_folder_shared (uon, path)) {
 		is_shared = TRUE;
-		if (check_share_offer_pending (uon, path))
-			is_share_offer_pending = TRUE;
 	}
 
 	if (ubuntuone_is_inside_shares (uon, path))
@@ -266,54 +212,6 @@ context_menu_new (UbuntuOneNautilus *uon,
 
 	g_object_weak_ref (G_OBJECT (root_item), (GWeakNotify) free_menu_cb_data, cb_data);
 
-	/* Share/unshare */
-	if ((is_managed || is_udf) && !is_root && is_dir && !is_symlink) {
-
-		menu_item = nautilus_menu_item_new ("ubuntuone-share",
-						    _("_Share..."),
-						    _("Share this folder on Ubuntu One"),
-						    "ubuntuone");
-		if (is_pending)
-			g_object_set (menu_item, "sensitive", FALSE, NULL);
-
-		g_signal_connect (menu_item, "activate",
-				  G_CALLBACK (share_folder_cb), cb_data);
-	} else {
-		/* the different tooltips will probably do us no good */
-		if (is_root) {
-			menu_item = nautilus_menu_item_new ("ubuntuone-noshare-root",
-							    _("_Share..."),
-							    _("Sorry, you can't share the root of a Ubuntu One volume"),
-							    "ubuntuone");
-		} else if (!(is_managed || is_udf)) {
-			menu_item = nautilus_menu_item_new ("ubuntuone-noshare-unmanaged",
-							    _("_Share..."),
-							    _("Sorry, you can't share folders not managed by Ubuntu One"),
-							    "ubuntuone");
-		} else {
-			menu_item = nautilus_menu_item_new ("ubuntuone-noshare-unmanaged",
-							    _("_Share..."),
-							    _("Sorry, you can only share folders"),
-							    "ubuntuone");
-		}
-		g_object_set (menu_item, "sensitive", FALSE, NULL);
-	}
-
-	nautilus_menu_append_item (submenu, menu_item);
-
-	if ((is_managed && is_shared) && !is_root && is_dir && !is_symlink) {
-		menu_item = nautilus_menu_item_new ("ubuntuone-unshare",
-						    _("Stop _Sharing"),
-						    _("Stop sharing this folder on Ubuntu One"),
-						    "ubuntuone");
-		if (is_pending || is_share_offer_pending)
-			g_object_set (menu_item, "sensitive", FALSE, NULL);
-
-		g_signal_connect (menu_item, "activate",
-				  G_CALLBACK (unshare_folder_cb), cb_data);
-		nautilus_menu_append_item (submenu, menu_item);
-	}
-
 	/* UDF logic
 	 *
 	 * XXX: clean this up and separate the logic out and reuse elsewhere
